DROP INDEX ppc_packages_idx;
DROP INDEX ppc_channels_idx;
DROP INDEX ppc_channels_assoc_idx;


DROP TABLE Channels CASCADE;
CREATE TABLE Channels (
	channel_label VARCHAR(80) NOT NULL PRIMARY KEY,
	channel_name VARCHAR(80) NOT NULL,
	channel_parent_label VARCHAR(80) ,
	channel_end_of_life timestamp,
        channel_arch VARCHAR(40),
        FOREIGN KEY (channel_parent_label) REFERENCES  Channels (channel_label)

	);


DROP TABLE Packages CASCADE;
CREATE TABLE Packages (
	package_id INTEGER NOT NULL PRIMARY KEY,
	package_arch_label VARCHAR(80) NOT NULL,
	package_name TEXT NOT NULL,
	package_epoch TEXT,
	package_version TEXT NOT NULL,
	package_release TEXT NOT NULL,
	package_last_modified_date timestamp
);


DROP TABLE Packages_Per_Channels  CASCADE;
CREATE TABLE Packages_Per_Channels (
	package_id INTEGER NOT NULL,
	channel_label VARCHAR(80) NOT NULL,
        is_latest boolean,
        FOREIGN KEY (package_id) REFERENCES Packages (package_id),
        FOREIGN KEY (channel_label) REFERENCES Channels (channel_label)

);


CREATE INDEX ppc_packages_idx on  Packages_Per_Channels (package_id);
CREATE INDEX ppc_channels_idx on  Packages_Per_Channels (channel_label);
CREATE INDEX ppc_channels_assoc_idx on  Packages_Per_Channels (package_id,channel_label);


DROP TABLE Erratas CASCADE;
CREATE TABLE Erratas (
	advisory VARCHAR(32) NOT NULL PRIMARY KEY,
	update_date TIMESTAMP,
	advisory_type VARCHAR(32),
	synopsis VARCHAR(128),
	last_modified_date TIMESTAMP,
	issue_date TIMESTAMP
);


DROP TABLE Advisory_Per_Packages CASCADE ;
-- There is no foreign key on package_id on purpose
-- because some package_id may be frm channel we do not 
-- support and for wich the package has not been imported
-- in the Packages table.
CREATE TABLE Advisory_Per_Packages (
	advisory VARCHAR(32) NOT NULL,
	package_id INTEGER NOT NULL,
	FOREIGN KEY (advisory) REFERENCES Erratas (advisory)
);
CREATE INDEX app_packages_idx on  Advisory_Per_Packages (package_id);


DROP TABLE Bugzillas CASCADE;
CREATE TABLE Bugzillas (
	bz_id INTEGER NOT NULL PRIMARY KEY,
	label VARCHAR(256)
);

DROP  TABLE Bz_Per_Advisory CASCADE;
CREATE TABLE Bz_Per_Advisory (
	advisory VARCHAR(32) NOT NULL,	
	bz_id INTEGER NOT NULL,
	FOREIGN KEY (advisory)  REFERENCES Erratas (advisory),
	FOREIGN KEY (bz_id)  REFERENCES Bugzillas (bz_id)
	
);
CREATE INDEX bpa_advisory_idx on Bz_Per_Advisory (advisory);
---DROP TABLE Packages;

---DROP TABLE Packages_in_Channels;

DROP TABLE unsupported_channels CASCADE;
CREATE TABLE unsupported_channels (
	channel_label VARCHAR(80)--,
--	 FOREIGN KEY (channel_label) REFERENCES  Channels (channel_label)
	
);




--
-- Data for Name: unsupported_channels; Type: TABLE DATA; Schema: public; Owner: checksosreport
--

COPY unsupported_channels (channel_label) FROM stdin;
severn-beta2-i386-updates
severn-beta2-i386
redhat-linux-severn-i386-9.0.93-updates
redhat-linux-severn-i386-9.0.93
redhat-linux-pSeries-7.1
redhat-linux-iSeries-7.1
redhat-linux-ia64-7.1
rhn-tools-redhat-linux-i386-9
education-k12ltsp-i386-9
redhat-linux-i386-9
education-k12ltsp-i386-8.0
redhat-linux-i386-8.0
redhat-gcc3.1-i386-7.3
education-k12ltsp-i386-7.3
education-general-i386-7.3
redhat-linux-i386-7.3
redhat-linux-s390-7.2
redhat-linux-ia64-7.2
redhat-rhn-satellite-2.0-i386-7.2
redhat-rhn-satellite-i386-7.2
redhat-rhn-proxy-i386-7.2
k12ltsp-i386-7.2
redhat-linux-i386-7.2
redhat-linux-s390x-7.1
redhat-linux-ee-i386-6.2
redhat-powertools-alpha-7.1
redhat-linux-alpha-7.1
redhat-powertools-i386-7.1
redhat-linux-i386-7.1
redhat-powertools-alpha-7.0
redhat-linux-alpha-7.0
redhat-powertools-i386-7.0
redhat-linux-i386-7.0
redhat-powertools-sparc-6.2
redhat-linux-sparc-6.2
redhat-powertools-alpha-6.2
redhat-linux-alpha-6.2
redhat-powertools-i386-6.2
redhat-linux-i386-6.2
solaris-sparc-9-rhdirserv-7.1-beta
solaris-sparc-9-rhdirserv-7.1
solaris-sparc-9-rhcmsys-7.1-beta
solaris-sparc-9-rhcmsys-7.1
solaris-sparc-9
solaris-sparc-9-rhcmsys-7.2
solaris-sparc-9-rhcmsys-7.2-beta
\.

DROP TABLE Changelogs CASCADE ;
CREATE TABLE Changelogs(
	short_date INT,
	date timestamp,
	changes TEXT,
	header VARCHAR(128),
	package_id INTEGER NOT NULL,
	FOREIGN KEY (package_id) REFERENCES Packages (package_id)
);
CREATE INDEX ch_entry_per_package_idx on Changelogs(package_id,date);

DROP TABLE  Files CASCADE;
CREATE TABLE Files(
	file_linkto VARCHAR(255),
	file_type VARCHAR(32),
	file_md5sum CHAR(32),
	file_size INT,
	file_path VARCHAR(128),
	file_last_modified_date timestamp,
	package_id INTEGER NOT NULL,
	FOREIGN KEY (package_id) REFERENCES Packages (package_id)
);
CREATE INDEX files_per_package_idx on Files(package_id);

-- Web tool tables:
DROP TABLE Spool CASCADE;
CREATE TABLE   Spool (
	id SERIAL PRIMARY KEY,
	email VARCHAR(32) NOT NULL,
	arch VARCHAR(32) NOT NULL,
	crm INTEGER NOT NULL,
	request_date TIMESTAMP DEFAULT 'now()',
	orig_file_name VARCHAR(32) NOT NULL
) WITH OIDS;

DROP TABLE  Status CASCADE;
CREATE TABLE Status (
        id integer NOT NULL,
        status varchar(32)
);

insert into Status (id,status) values (1,'idle');

